@@ -7,7 +7,7 @@ use warnings;
 use English qw< -no_match_vars >;
 use Data::Dumper;
 use Scalar::Util qw< blessed >;
-our $VERSION = '0.735';
+our $VERSION = '0.735001';
 
 use Log::Log4perl::Tiny
   qw< :easy :dead_if_first get_logger LOGLEVEL LEVELID_FOR >;
@@ -67,7 +67,7 @@ sub cache {
 
    # the cache! We will use something compatible with CHI
    my $cache = $args{cache} // {};
-   $cache = ['!Data::Tubes::Util::Cache', repository => $cache]
+   $cache = ['^Data::Tubes::Util::Cache', repository => $cache]
      if ref($cache) eq 'HASH';
    if (!blessed($cache)) {
       my ($x, @args) = ref($cache) ? @$cache : $cache;
