@@ -2,7 +2,7 @@ package Data::Tubes::Plugin::Validator;
 use strict;
 use warnings;
 use English qw< -no_match_vars >;
-our $VERSION = '0.735';
+our $VERSION = '0.735001';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -88,7 +88,7 @@ sub validate_thoroughly {
    my $wrapper = $args->{wrapper};
    if ($wrapper && $wrapper eq 'try') {
       eval { require Try::Tiny; }
-        or LOGCONFESS '+Validator::validate_with_subs '
+        or LOGCONFESS 'Validator::validate_with_subs '
         . 'needs Try::Tiny, please install';
 
       $wrapper = sub {
